# anamon.py - methods for collecting log data from client machines
#
# Copyright 2008 Red Hat, Inc.
#
# This copyrighted material is made available to anyone wishing to use, modify,
# copy, or redistribute it subject to the terms and conditions of the GNU
# General Public License v.2.  This program is distributed in the hope that it
# will be useful, but WITHOUT ANY WARRANTY expressed or implied, including the
# implied warranties of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 51
# Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  Any Red Hat
# trademarks that are incorporated in the source code or documentation are not
# subject to the GNU General Public License and may only be used or replicated
# with the express permission of Red Hat, Inc. 
#
# Author: Will Woods <wwoods@redhat.com>
# 
# Inspired by Mike McLean's anamon stuff. Hi, Mike.

import os
import snake.config
import string

def start_task(name='task'):
    '''Creates a new logging task. Returns a task ID.'''
    # Create a directory of the form: logging_dir/taskname/X, where X is the 
    # first available number in the 'taskname' dir. 
    # Return taskname/X.
    name = _sanitize(name)

    topdir = snake.config.getoption('logging_dir')
    assert topdir
    # make sure logging_dir exists
    if not os.path.isdir(topdir):
        os.mkdir(topdir)

    dir = os.path.join(topdir,name)
    task_num = 1
    if not os.path.isdir(dir):
        os.mkdir(dir)
    else:
        existing_dirs = os.listdir(dir)
        # FIXME: O(n^2) worst case. 
        while str(task_num) in existing_dirs:
            task_num += 1
    task_id = os.path.join(name,str(task_num))
    os.mkdir(os.path.join(topdir,task_id))
    return task_id

def _get_taskdir(task):
    '''Return the full path to the taskdir for the given task, or an
    empty string if the given task does not yet exist.'''
    dir = os.path.join(snake.config.getoption('logging_dir'),task)
    if os.path.isdir(dir):
        return dir
    else:
        return ''

# List of chars allowed in filenames
_safe_chars = string.ascii_letters + string.digits + ' _-'
def _sanitize(filename):
    '''Sanitize the given filename; replace anything that's not in
    %s with _''' % _safe_chars
    r = ''
    for c in filename:
        if c not in _safe_chars:
            r += '_'
        else:
            r += c
    return r

def update_file(task,filename,data):
    '''Append data to the named file in the given task.
    An exception will be raised if the task does not exist.
    The file will be created if it does not already exist.
    Returns the number of bytes written.
    '''
    filename = _sanitize(filename)
    taskdir = _get_taskdir(task)
    f = open(os.path.join(taskdir,filename),'a')
    r = f.write(data)
    f.close()
    return len(data)

def remove_file(task,filename):
    '''NOT IMPLEMENTED.'''
    raise NotImplementedError

def remove_task(task):
    '''NOT IMPLEMENTED.'''
    raise NotImplementedError
