#
# config.py - configuration for snake stuff
#
# Copyright 2006, 2007 Red Hat, Inc.
#
# This copyrighted material is made available to anyone wishing to use, modify,
# copy, or redistribute it subject to the terms and conditions of the GNU
# General Public License v.2.  This program is distributed in the hope that it
# will be useful, but WITHOUT ANY WARRANTY expressed or implied, including the
# implied warranties of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 51
# Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  Any Red Hat
# trademarks that are incorporated in the source code or documentation are not
# subject to the GNU General Public License and may only be used or replicated
# with the express permission of Red Hat, Inc. 
#

from ConfigParser import ConfigParser
from socket import gethostname,gethostbyaddr,gaierror

def getipaddr():
    try:
        return gethostbyaddr(gethostname())[-1][0]
    except gaierror:
        '''on some systems the hostname may not be a reverse mappable'''
        return "0.0.0.0"

DEFAULT_CONFIGFILE = "/etc/snake.conf"
DEFAULT_HOSTNAME = gethostname()
DEFAULT_IPADDR = getipaddr()
DEFAULT_PORT = 2903 # used by "suitcase".. but do we care?

# Default configs
defaults={
    "server": {
        "hostname":             DEFAULT_HOSTNAME,
        "listen":               DEFAULT_IPADDR,
        "port":                 DEFAULT_PORT,
        "zeroconf":             "yes",
        "sname":                "SNAKE",
        "ftp_root":             "/snake",                   # root directory used by ftp clients
        "http_root":            "/snake",                   # root directory used by http clients
        "nfs_dir":              "/var/lib/snake/machines",  # directory used by nfs clients
        "ksmethods":            "http ftp nfs",             # Supported schemas for accessing kickstarts
        "logging_dir":          "/var/lib/snake/logging",   # root dir for client log data
        "xmlcachedir":          "/var/cache/snake",
        "plugindir":            "/var/lib/snake/plugins",
        "templatedir":          "/var/lib/snake/templates",
        "ksdb_dir":             "/var/lib/snake/kickstarts",
        "treedb_dir":           "/var/lib/snake/trees",
        "machinedb_dir":        "/var/lib/snake/machines",
        "logfile":              "/var/log/snake",
        "xmlcache_refresh":     "10",
        "puthandler_enabled":   "no"
    }
}

config = None

def _loadconfig(section, filename):
    parser = ConfigParser(defaults[section])
    parser.read(filename)
    configlist = parser.items(section,True)
    return dict(configlist)

def getconfig(section="server", filename=DEFAULT_CONFIGFILE, reload=False):
    global config
    if reload or config == None:
        config = _loadconfig(section, filename)
    return config

def getoption(option, default=None, section="server", reload=False):
    global config
    config = getconfig(section, reload=reload)
    return config.get(option,default)

if __name__ == '__main__':
    import sys
    c=getconfig(sys.argv[1])
    print c[sys.argv[2]]
